# Data folder
The folders in this subdirectory contains some sets of data used by xpecgen.

Each of this folders should contain a readme file explaining:
- What is the **origin** of the data, including a reference if possible.
- **How** the data was **obtained**.
- Explanations on the content of the **files**, including the physical meaning, units and data structure.
